﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2010 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using HeuristicLab.Clients.Common;
using HeuristicLab.Collections;
using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.PluginInfrastructure;

namespace HeuristicLab.Clients.OKB {
  [Item("Administrator", "OKB administrator front-end.")]
  public sealed class Administrator : IContent {
    private ItemCollection<AlgorithmClass> algorithmClasses;
    public ItemCollection<AlgorithmClass> AlgorithmClasses {
      get { return algorithmClasses; }
    }
    private ItemCollection<Algorithm> algorithms;
    public ItemCollection<Algorithm> Algorithms {
      get { return algorithms; }
    }

    public Administrator() {
      algorithmClasses = new ItemCollection<AlgorithmClass>();
      algorithms = new ItemCollection<Algorithm>();

      algorithmClasses.ItemsRemoved += new CollectionItemsChangedEventHandler<AlgorithmClass>(algorithmClasses_ItemsRemoved);
      algorithms.ItemsRemoved += new CollectionItemsChangedEventHandler<Algorithm>(algorithms_ItemsRemoved);
    }

    public void Refresh() {
      using (AdminServiceClient adminService = ClientFactory.CreateClient<AdminServiceClient, IAdminService>()) {
        try {
          algorithmClasses.Clear();
          algorithmClasses.AddRange(adminService.GetAlgorithmClasses());
          algorithms.Clear();
          algorithms.AddRange(adminService.GetAlgorithms());
        }
        catch (Exception ex) {
          ErrorHandling.ShowErrorDialog(ex);
        }
      }
    }

    private void algorithmClasses_ItemsRemoved(object sender, CollectionItemsChangedEventArgs<AlgorithmClass> e) {
      using (AdminServiceClient adminService = ClientFactory.CreateClient<AdminServiceClient, IAdminService>()) {
        foreach (AlgorithmClass ac in e.Items)
          adminService.DeleteAlgorithmClass(ac.Id);
      }
    }
    private void algorithms_ItemsRemoved(object sender, CollectionItemsChangedEventArgs<Algorithm> e) {
      using (AdminServiceClient adminService = ClientFactory.CreateClient<AdminServiceClient, IAdminService>()) {
        foreach (Algorithm a in e.Items)
          adminService.DeleteAlgorithm(a.Id);
      }
    }
  }
}
