#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2010 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.ComponentModel;
using System.Windows.Forms;
using HeuristicLab.Core.Views;
using HeuristicLab.MainForm;
using HeuristicLab.MainForm.WindowsForms;

namespace HeuristicLab.Clients.OKB {
  [View("OKBItem View")]
  [Content(typeof(OKBItem), true)]
  [Content(typeof(IOKBItem), false)]
  public partial class OKBItemView : ItemView {
    public new IOKBItem Content {
      get { return (IOKBItem)base.Content; }
      set { base.Content = value; }
    }

    public OKBItemView() {
      InitializeComponent();
    }

    protected override void DeregisterContentEvents() {
      Content.PropertyChanged -= new PropertyChangedEventHandler(Content_PropertyChanged);
      base.DeregisterContentEvents();
    }
    protected override void RegisterContentEvents() {
      base.RegisterContentEvents();
      Content.PropertyChanged += new PropertyChangedEventHandler(Content_PropertyChanged);
    }

    protected override void SetEnabledStateOfControls() {
      base.SetEnabledStateOfControls();
      storeButton.Enabled = Content != null;
    }

    private void Content_PropertyChanged(object sender, PropertyChangedEventArgs e) {
      if (InvokeRequired)
        Invoke(new PropertyChangedEventHandler(Content_PropertyChanged), sender, e);
      else {
        OnContentPropertyChanged(e.PropertyName);
      }
    }
    protected virtual void OnContentPropertyChanged(string propertyName) { }

    protected virtual void storeButton_Click(object sender, EventArgs e) {
      Content.Store();
    }
  }
}
